@@ -20,8 +20,8 @@ def salt_master(salt_factories, master_id):
     """
     This fixture just configures and starts a salt-master.
     """
-    config_overrides = {"open_mode": True}
-    factory = salt_factories.get_salt_master_daemon(master_id, config_overrides=config_overrides)
+    overrides = {"open_mode": True}
+    factory = salt_factories.salt_master_daemon(master_id, overrides=overrides)
     with factory.started():
         yield factory
 
@@ -31,7 +31,7 @@ def salt_minion(salt_factories, minion_id, salt_master):
     """
     This fixture just configures and starts a salt-minion.
     """
-    factory = salt_master.get_salt_minion_daemon(minion_id)
+    factory = salt_master.salt_minion_daemon(minion_id)
     with factory.started():
         yield factory
 
