@@ -5,14 +5,14 @@ from saltfactories.utils import random_string
 
 @pytest.fixture(scope="module")
 def master(salt_factories):
-    factory = salt_factories.get_salt_master_daemon(random_string("master-"))
+    factory = salt_factories.salt_master_daemon(random_string("master-"))
     with factory.started():
         yield factory
 
 
 @pytest.fixture(scope="module")
 def minion(master):
-    factory = master.get_salt_minion_daemon(random_string("minion-"))
+    factory = master.salt_minion_daemon(random_string("minion-"))
     with factory.started():
         yield factory
 
@@ -24,7 +24,7 @@ def salt_cli(master):
 
 @pytest.fixture
 def salt_call_cli(minion):
-    return minion.get_salt_call_cli()
+    return minion.salt_call_cli()
 
 
 def test_minion(minion, salt_cli):
@@ -64,3 +64,13 @@ def test_salt_call_exception_handling_doesnt_timeout(minion, salt_call_cli):
         "test.raise_exception", "OSError", "2", "No such file or directory", "/tmp/foo.txt"
     )
     assert ret.exitcode == 1, ret
+
+
+def test_state_tree(minion, salt_call_cli):
+    sls_contents = """
+    test:
+      test.succeed_without_changes
+    """
+    with minion.state_tree.base.temp_file("foo.sls", sls_contents):
+        ret = salt_call_cli.run("--local", "state.sls", "foo")
+        assert ret.exitcode == 0
